==> 0.0.50.tar.gz: lib/DemoComponent.dart <==
/*
    Refer License for Terms & Conditions
 */
import 'package:flutter/material.dart';
import 'package:bui_component/Constants/AppColors.dart';

// ignore: must_be_immutable
class DemoComponent extends StatefulWidget {
  final Function() onMenuPressed;
  final Color backgroundColor;

  DemoComponent({
    Key key,
    @required this.onMenuPressed,
    @required this.backgroundColor,
  });

  @override
  _DemoComponentState createState() => _DemoComponentState();
}

class _DemoComponentState extends State<DemoComponent> {

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: AppColors.APP_COLOR_WHITE,
      body: SafeArea(
        child: Center(
          child: Column(
            children: <Widget>[
              Container(
                height: 60,
                color: widget.backgroundColor != null
                    ? widget.backgroundColor
                    : AppColors.APP_COLOR_PRIMARY,
                child: Row(
                  children: <Widget>[
                    ClipRRect(
                      borderRadius: BorderRadius.all(Radius.circular(32.0)),
                      child: InkWell(
                        splashColor: AppColors.errorWarning,
                        focusColor: AppColors.APP_COLOR_WHITE,
                        onTap: () {
                          widget.onMenuPressed();
                        },
                        child: Padding(
                          padding: const EdgeInsets.all(12.0),
                          child: Icon(
                            Icons.menu,
                            color: Colors.white,
                          ),
                        ),
                      ),
                    ),
                    SizedBox(
                      width: 130,
                    ),
                    ClipRRect(
                      borderRadius: BorderRadius.all(Radius.circular(32.0)),
                      child: InkWell(
                        splashColor: AppColors.errorWarning,
                        focusColor: AppColors.APP_COLOR_WHITE,
                        onTap: () {
                          //widget.onMenuPressed();
                        },
                        child: Padding(
                          padding: const EdgeInsets.all(12.0),
                          child: Icon(
                            Icons.notifications_active,
                            color: Colors.white,
                          ),
                        ),
                      ),
                    ),
                    SizedBox(
                      width: 10,
                    ),
                    ClipRRect(
                      borderRadius: BorderRadius.all(Radius.circular(32.0)),
                      child: InkWell(
                        splashColor: AppColors.errorWarning,
                        focusColor: AppColors.APP_COLOR_WHITE,
                        onTap: () {
                          //widget.onMenuPressed();
                        },
                        child: Padding(
                          padding: const EdgeInsets.all(12.0),
                          child: Icon(
                            Icons.settings,
                            color: Colors.white,
                          ),
                        ),
                      ),
                    ),
                    SizedBox(
                      width: 10,
                    ),
                    ClipRRect(
                      borderRadius: BorderRadius.all(Radius.circular(32.0)),
                      child: InkWell(
                        splashColor: AppColors.errorWarning,
                        focusColor: AppColors.APP_COLOR_WHITE,
                        onTap: () {
                          //widget.onMenuPressed();
                        },
                        child: Padding(
                          padding: const EdgeInsets.all(12.0),
                          child: Icon(
                            Icons.messenger_rounded,
                            color: Colors.white,
                          ),
                        ),
                      ),
                    ),
                  ],
                ),
              ),
              Expanded(
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: <Widget>[
                    Text('Demo Screen'),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> 0.0.63.tar.gz: lib/DemoComponent.dart <==
/*
    Refer License for Terms & Conditions
 */
import 'package:flutter/material.dart';
import 'package:bui_component/Constants/AppColors.dart';

// ignore: must_be_immutable
class DemoComponent extends StatefulWidget {
  final Function() onMenuPressed;
  final Color backgroundColor;

  DemoComponent({
    Key key,
     this.onMenuPressed,
     this.backgroundColor,
  });

  @override
  _DemoComponentState createState() => _DemoComponentState();
}

class _DemoComponentState extends State<DemoComponent> {

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: AppColors.APP_COLOR_WHITE,
      body: SafeArea(
        child: Center(
          child: Column(
            children: <Widget>[
              Container(
                height: 60,
                color: widget.backgroundColor != null
                    ? widget.backgroundColor
                    : AppColors.APP_COLOR_PRIMARY,
                child: Row(
                  children: <Widget>[
                    ClipRRect(
                      borderRadius: BorderRadius.all(Radius.circular(32.0)),
                      child: InkWell(
                        splashColor: AppColors.errorWarning,
                        focusColor: AppColors.APP_COLOR_WHITE,
                        onTap: () {
                          widget.onMenuPressed();
                        },
                        child: Padding(
                          padding: const EdgeInsets.all(12.0),
                          child: Icon(
                            Icons.menu,
                            color: Colors.white,
                          ),
                        ),
                      ),
                    ),
                    SizedBox(
                      width: 130,
                    ),
                    ClipRRect(
                      borderRadius: BorderRadius.all(Radius.circular(32.0)),
                      child: InkWell(
                        splashColor: AppColors.errorWarning,
                        focusColor: AppColors.APP_COLOR_WHITE,
                        onTap: () {
                          //widget.onMenuPressed();
                        },
                        child: Padding(
                          padding: const EdgeInsets.all(12.0),
                          child: Icon(
                            Icons.notifications_active,
                            color: Colors.white,
                          ),
                        ),
                      ),
                    ),
                    SizedBox(
                      width: 10,
                    ),
                    ClipRRect(
                      borderRadius: BorderRadius.all(Radius.circular(32.0)),
                      child: InkWell(
                        splashColor: AppColors.errorWarning,
                        focusColor: AppColors.APP_COLOR_WHITE,
                        onTap: () {
                          //widget.onMenuPressed();
                        },
                        child: Padding(
                          padding: const EdgeInsets.all(12.0),
                          child: Icon(
                            Icons.settings,
                            color: Colors.white,
                          ),
                        ),
                      ),
                    ),
                    SizedBox(
                      width: 10,
                    ),
                    ClipRRect(
                      borderRadius: BorderRadius.all(Radius.circular(32.0)),
                      child: InkWell(
                        splashColor: AppColors.errorWarning,
                        focusColor: AppColors.APP_COLOR_WHITE,
                        onTap: () {
                          //widget.onMenuPressed();
                        },
                        child: Padding(
                          padding: const EdgeInsets.all(12.0),
                          child: Icon(
                            Icons.messenger_rounded,
                            color: Colors.white,
                          ),
                        ),
                      ),
                    ),
                  ],
                ),
              ),
              Expanded(
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: <Widget>[
                    Text('Demo Screen'),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
